@@ -6,7 +6,9 @@ require 'specinfra/backend/powershell/command'
 require 'specinfra/backend/cmd'
 require 'specinfra/backend/docker'
 require 'specinfra/backend/lxc'
+require 'specinfra/backend/lxd'
 require 'specinfra/backend/winrm'
 require 'specinfra/backend/shell_script'
 require 'specinfra/backend/dockerfile'
 require 'specinfra/backend/telnet'
+require 'specinfra/backend/jexec'
