@@ -1,7 +1,7 @@
 class Specinfra::Command::Linux::Base::File < Specinfra::Command::Base::File
   class << self
     def check_is_accessible_by_user(file, user, access)
-      "su -s /bin/sh -c \"test -#{access} #{file}\" #{user}"
+      "sudo -u #{user} test -#{access} #{file}"
     end
 
     def check_is_immutable(file)
