@@ -8,6 +8,10 @@ class Specinfra::Command::Linux::Base::Interface < Specinfra::Command::Base::Int
       "cat /sys/class/net/#{name}/speed"
     end
 
+    def get_mtu_of(name)
+      "cat /sys/class/net/#{name}/mtu"
+    end
+
     def check_has_ipv4_address(interface, ip_address)
       ip_address = ip_address.dup
       if ip_address =~ /\/\d+$/
@@ -16,7 +20,7 @@ class Specinfra::Command::Linux::Base::Interface < Specinfra::Command::Base::Int
         ip_address << "/"
       end
       ip_address.gsub!(".", "\\.")
-      "ip addr show #{interface} | grep 'inet #{ip_address}'"
+      "ip -4 addr show #{interface} | grep 'inet #{ip_address}'"
     end
 
     def check_has_ipv6_address(interface, ip_address)
@@ -27,7 +31,15 @@ class Specinfra::Command::Linux::Base::Interface < Specinfra::Command::Base::Int
         ip_address << "/"
       end
       ip_address.downcase!
-      "ip addr show #{interface} | grep 'inet6 #{ip_address}'"
+      "ip -6 addr show #{interface} | grep 'inet6 #{ip_address}'"
+    end
+
+    def get_ipv4_address(interface)
+      "ip -4 addr show #{interface} | grep #{interface}$ | awk '{print $2}'"
+    end
+
+    def get_ipv6_address(interface)
+      "ip -6 addr show #{interface} | grep inet6 | awk '{print $2}'"
     end
 
     def get_link_state(name)
@@ -35,4 +47,3 @@ class Specinfra::Command::Linux::Base::Interface < Specinfra::Command::Base::Int
     end
   end
 end
-
